import { MinusCircleOutlined, PlusOutlined } from "@ant-design/icons";
import {
  Button,
  Checkbox,
  Col,
  Form,
  Input,
  Radio,
  Row,
  Space,
  Typography,
} from "antd";
const { Text } = Typography;
import {} from "antd";
import { useEffect, useState } from "react";
import "./index.less";

interface IProps {
  onChange?: Function;
  styles?: React.CSSProperties;
}

interface IChapter {
  level: string;
  title: string;
  fileId?: string;
}

const Chatpter = (props: IProps) => {
  const [form] = Form.useForm();
  const [chapterList, setChapterList] = useState<IChapter[]>([]);

  const onTocChange = () => {
    const { toc } = form.getFieldsValue();
    const process = toc.split("\n").map((row: string) => {
      const [level, title, fileId] = row.split("|");
      return !fileId ? { level, title } : { level, title, fileId };
    });
    setChapterList(process);
  };

  useEffect(() => {
    if (props.onChange) props.onChange(chapterList);
  }, [chapterList]);

  return (
    <div style={{ ...props.styles }}>
      <Row gutter={24}>
        <Col span={12}>
          <Form form={form} onChange={onTocChange}>
            <Form.Item name="toc">
              <Input.TextArea
                placeholder="级别|标题|FileId"
                style={{ minHeight: 600, lineHeight: 2, fontSize: 16 }}
              ></Input.TextArea>
            </Form.Item>
          </Form>
        </Col>
        <Col span={12}>
          <ul className="chapter-list">
            {chapterList.map((chapter, index) => (
              <li
                key={index}
                className={+chapter.level === 1 ? "l1" : ""}
                style={{ paddingLeft: +chapter.level === 1 ? 0 : 20 }}
              >
                <Text style={{ fontSize: +chapter.level === 1 ? 18 : 16 }}>
                  {chapter.title}
                </Text>
                {chapter.fileId && (
                  <Text type="secondary">{chapter.fileId}</Text>
                )}
              </li>
            ))}
          </ul>
        </Col>
      </Row>
    </div>
  );
};

export default Chatpter;
