import { Button, Card, Drawer, Input, message, Steps, Typography } from "antd";
import { useEffect, useState } from "react";
import Guide from "./Guide";
import BasicForm from "./BasicForm";
import Chatpter from "./Chatpter";
import "./index.less";
import { useMediaStore } from "../../../store/media";
const { Text } = Typography;

const CourseCreate = () => {
  const [current, setCurrent] = useState(0);
  const [course, setCourse] = useState({
    basicInfo: {},
    chapters: [],
    guide: {},
  });

  const onBasicFormChange = (form: any) =>
    setCourse((p) => ({ ...p, basicInfo: form }));

  const steps = [
    {
      title: "基本信息",
    },
    {
      title: "章节",
    },
    {
      title: "导读",
    },
  ];

  const [createBtnValid, setCreateBtnValid] = useState(true);

  const items = steps.map((item) => ({ key: item.title, title: item.title }));

  const onChapterChange = (chapters: any) =>
    setCourse((p) => ({ ...p, chapters }));

  const onGuideChange = ({ value, html }: { value: string; html: string }) => {
    setCourse((p) => ({ ...p, guide: { value, html } }));
  };

  const onClickCreate = () => {
    console.log(course);
    message.info("撒打算");
  };

  useEffect(() => {
    const basicValid = !Object.values(course.basicInfo).includes("");
    const chaptersValid = course.chapters.length !== 0;
    const guideValid = !Object.values(course.guide).includes("");
    setCreateBtnValid(basicValid && chaptersValid && guideValid);
  }, [course]);

  const mediaList = useMediaStore((s: any) => s.listFilter);

  const mediaListFilter = useMediaStore((s: any) => s.filterList);

  const [open, setOpen] = useState(false);

  const showDrawer = () => {
    setOpen(true);
  };

  const onClose = () => {
    setOpen(false);
  };

  const onSearchChange = (e: any) => {
    mediaListFilter(e.target.value);
  };

  return (
    <div className="create-course">
      <Card>
        <Steps current={current} items={items} />
        <div className="content">
          <BasicForm
            onChange={onBasicFormChange}
            styles={{ display: current === 0 ? "block" : "none" }}
          />
          <Chatpter
            onChange={onChapterChange}
            styles={{ display: current === 1 ? "block" : "none" }}
          />
          <Guide
            onChange={onGuideChange}
            styles={{ display: current === 2 ? "block" : "none" }}
          />
        </div>
        <div style={{ textAlign: "right", marginTop: "40px" }}>
          {current === 1 && (
            <Button
              type="primary"
              onClick={showDrawer}
              style={{ marginRight: "12px" }}
            >
              视频库
            </Button>
          )}
          {current > 0 && (
            <Button
              style={{ marginRight: "12px" }}
              onClick={() => setCurrent(current - 1)}
            >
              上一步
            </Button>
          )}
          {current < steps.length - 1 && (
            <Button type="primary" onClick={() => setCurrent(current + 1)}>
              下一步
            </Button>
          )}
          {current === steps.length - 1 && (
            <Button
              type="primary"
              onClick={onClickCreate}
              disabled={!createBtnValid}
            >
              创建
            </Button>
          )}
        </div>
      </Card>
      <Drawer title="媒体库" placement="right" onClose={onClose} open={open}>
        <Input placeholder={`根据名称搜索`} onChange={onSearchChange} />
        <section style={{ marginTop: 24 }}>
          {mediaList.map((media: any) => {
            return (
              <div key={media.key} className="drawer-media-item">
                <div>{media.name}</div>
                <Text type="secondary">{media.key}</Text>
              </div>
            );
          })}
        </section>
      </Drawer>
    </div>
  );
};

export default CourseCreate;
