import { Inject, Post, Body, Files, Controller } from '@midwayjs/core';
import { Context } from 'koa';
import { BizCode } from '../biz/code';
import * as tencentcloud from 'tencentcloud-sdk-nodejs';
import { VodSearchDTO } from '../dto/vod.dto';
import { uploadImagePromise } from '../util/vod';
import { IVodResponse } from '../interface';

@Controller('/vod')
export class VodController {
  @Inject()
  ctx: Context;
  /**
   * 腾讯媒资管理查询
   * API调用demo: https://console.cloud.tencent.com/api/explorer?Product=vod&Version=2018-07-17&Action=SearchMedia
   * 最大返回5000条数据
   */
  @Post('/media/select')
  async getCourseMediaList(@Body() param: VodSearchDTO) {
    const { offset: Offset = 0, limit: Limit = 5000 } = param;
    const VodClient = tencentcloud.vod.v20180717.Client;
    const clientConfig = {
      credential: {
        secretId: process.env.SECRET_ID,
        secretKey: process.env.SECRET_KEY,
      },
      profile: {
        httpProfile: {
          endpoint: 'vod.tencentcloudapi.com',
        },
      },
    };
    const client = new VodClient(clientConfig);
    const params = {
      SubAppId: +process.env.SUBAPPID,
      Categories: ['Video'],
      Offset,
      Limit,
    };
    return await client.SearchMedia(params).then(
      data => ({ code: BizCode.OK, data }),
      err => {
        this.ctx.logger.error(err);
        throw new Error(err);
      }
    );
  }

  /**
   * 后台管理：上传课程封面图
   */
  @Post('/course/cover/upload')
  async uploadCourseCoverImage(@Files() files) {
    const tmpPath = files[0].data;
    return await uploadImagePromise(tmpPath, +process.env.SUBAPPID)
      .then((data: IVodResponse) => ({ code: BizCode.OK, data }))
      .catch(err => {
        this.ctx.logger.error(err);
        throw new Error(err);
      });
  }

  /**
   * 图片单个上传
   */
  @Post('/oss/image/upload')
  async ossUploadImage(@Files() files) {
    const tmpPath = files[0].data;
    return await uploadImagePromise(tmpPath, +process.env.SUBAPPID_OSS)
      .then((data: IVodResponse) => ({
        code: BizCode.OK,
        data: { name: data.FileId, url: data.MediaUrl },
      }))
      .catch(err => {
        this.ctx.logger.error(err);
        return { code: BizCode.ERROR, msg: err };
      });
  }
}
